/*
AbstractActivity is a basic visual container that can be pushed onto the ActivityStack.
It can set its preferred application header style.
It doesn't create a page row - this allows to have multiple page rows inside one activity,
e.g. in an archive browser application the BrowserActivity could contain Browser object
for each opened archive. Each Browser object would have its own page row:

// Inside Browser.qml
FocusScope {
    anchors.fill: parent

    property alias pageRow: __pageRow

    KirigamiPatched.PageRow {
        id: __pageRow
        anchors.fill: parent
        focus: true
    }

    property string archiveName

    // other data, etc.
}

And the 'pageRow' property inside ArchiveBrowser would bind to currently selected Browser's pageRow:

// Inside BrowserActivity.qml
Activity {
    id: root
    property var browsers: []
    property Item currentBrowser

    function activateBrowser(index) {
        currentBrowser.parent = null
        currentBrowser = browsers[index]
        currentBrowser.parent = root
        pageRow = Qt.binding(function() { return currentBrowser.pageRow })
    }

    // other data, etc.
}
*/

import QtQuick 2.0

import org.kde.kirigami 2.0 as Kirigami

FocusScope {
    id: root

    property int preferredApplicationHeaderStyle : Kirigami.ApplicationHeaderStyle.Auto
    // copy-paste from Kirigami.AbstractApplicationWindow
    property bool wideScreen: width >= Kirigami.Units.gridUnit * 60
    property Item background
    property Item pageRow

    onPageRowChanged: {
        if (pageRow)
            pageRow.parent = root
    }
}
