/*
This project shows how to create an application with two activities.
The first one, BrowserActivity is always enabled and SettingsActivity is pushed
onto the ActivityStack when user clicks 'Settings' button.
Each activity sets its preferred ApplicationHeaderStyle.
In general, when going back from SettingsActivity to BrowserActivity
the state of each page in the BrowserAActivity (e.g. scroll position)
should be the same as when the user has left the activity.
However for some reason this is not entirely the case
and scroll positions are sligthly different.
*/

import QtQuick 2.7
import QtQuick.Controls 2.0

import org.kde.kirigami 2.0 as Kirigami

import "../kirigami-new/kirigami-patched" as KirigamiPatched
import "../kirigami-new/kirigami-addons" as KirigamiAddons

KirigamiPatched.ApplicationWindow {
    id: root

    property Item settingsActivity
    /*
    The current idea is that handling of activities' signals takes place in application logic,
    because only there you know the current state of the program and
    how to react to these signals, e.g. current activity could be just
    popped from the stack or replaced with another activity - ActivityStack and Activity
    don't know what to do after Activity has finished. Also when creating
     activities some additional work is done e.g. connecting signals or configuration.
     */
    function onSettingsActivityFinished() {
        settingsActivity = null
        activityStack.pop()
    }

    // When activity stack is ready, a default activity (BrowserActivity) is created
    // and pushed onto the stack, so it becomes visible.
    Connections {
        target: activityStack
        onCompleted: {
            var component = Qt.createComponent("BrowserActivity.qml")
            var activity = component.createObject()
            activityStack.push(activity)
        }
    }

    header: KirigamiPatched.ApplicationHeader {
    }

    globalDrawer: Kirigami.GlobalDrawer {
        id: globalDrawer
        // the binding for handleVisible from src/controls/templates/OverlayDrawer.qml
        // doesn't seem to work; also don't show handle in settings activity
        handleVisible: controlsVisible && !settingsActivity
        // same here, the value for drawerOpen from src/controls/templates/OverlayDrawer.qml
        // doesn't seem to work
        drawerOpen: false
        actions: [
            Kirigami.Action{
                text:"Settings"
                onTriggered: {
                    if (!settingsActivity){
                        var component = Qt.createComponent("SettingsActivity.qml")
                        settingsActivity = component.createObject()
                        settingsActivity.onFinished.connect(root.onSettingsActivityFinished)
                        activityStack.push(settingsActivity)
                    }
                    globalDrawer.close()
                }
            },
            Kirigami.Action{
                text:"Quit"
                onTriggered: Qt.quit()
            }
        ]
    }
}
