/*
This project shows the simplest usage of Kirigami-New:
one activity and one page row
*/

import QtQuick 2.7
import QtQuick.Controls 2.0

import org.kde.kirigami 2.0 as Kirigami

import "../kirigami-new/kirigami-patched" as KirigamiPatched
import "../kirigami-new/kirigami-addons" as KirigamiAddons

// ApplicationWindow creates ActivityStack
KirigamiPatched.ApplicationWindow {
    id: root

    activityStack.initialActivity: KirigamiAddons.Activity {
        // "initialPage:" is a shortcut - inside activity we could use "pageRow.initialPage:"
        initialPage: KirigamiPatched.Page {
            title: "Page 1"
            anchors.fill: parent
            contextualActions: [
                Kirigami.Action {text: "Action 1"},
                Kirigami.Action {text: "Action 2"}
            ]
            Rectangle {
                anchors.fill: parent
                color: "dark gray"
            }
        }
    }

    // additional pages can only be added after ActivityStack has been completed
    Connections {
        target: activityStack
        onCompleted: {
            activityStack.currentActivity.pageRow.push(pageComponent.createObject(null,{"title":"Page 2"}))
            activityStack.currentActivity.pageRow.push(pageComponent.createObject(null,{"title":"Page 3"}))
        }
    }

    Component {
        id: pageComponent
        KirigamiPatched.Page{
            anchors.fill: parent
            Rectangle {
                anchors.fill: parent
                color: "light gray"
            }
        }
    }

    header: KirigamiPatched.ApplicationHeader {
    }

    globalDrawer: Kirigami.GlobalDrawer {
        // the binding for handleVisible from src/controls/templates/OverlayDrawer.qml
        // doesn't seem to work
        handleVisible: controlsVisible
        // same here, the value for drawerOpen from src/controls/templates/OverlayDrawer.qml
        // doesn't seem to work
        drawerOpen: false
        actions: [
           Kirigami.Action {
               text: "Quit"
           }
        ]
    }

    contextDrawer: KirigamiPatched.ContextDrawer {
    }
}
